gedidb.GEDIDatabase
===================

.. currentmodule:: gedidb

.. autoclass:: GEDIDatabase

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GEDIDatabase.__init__
      ~GEDIDatabase.check_granules_status
      ~GEDIDatabase.consolidate_fragments
      ~GEDIDatabase.mark_granule_as_processed
      ~GEDIDatabase.spatial_chunking
      ~GEDIDatabase.write_granule
   
   

   
   
   